@@ -42,7 +42,7 @@ def draw():
 
     db.commit()
     
-def insert(name:str,path:str):
+def insert_data(name:str,path:str):
     
     if not os.path.exists(path):
         print("path not found ")
@@ -64,7 +64,7 @@ def insert(name:str,path:str):
 
     db.commit()
 
-def update_val(name,path):
+def update_data(name,path):
     if not os.path.exists(path):
         print("path not found ")
         exit()
