@@ -1,7 +1,6 @@
 import typer
 import os
-from .db import delete, draw,fetch,drop
-from .db import insert as insert_data
+from .db import delete, draw,fetch,drop,update_data,insert_data
 
 
 
@@ -23,6 +22,11 @@ def insert(name,path):
     insert_data(name,path)
 
 
+@app.command()
+def update(name,path):
+    update_data(name,path)
+
+
 
 @app.command()
 def get(name):
